import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockInfo(_message.Message):
    __slots__ = ("height", "timestamp")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    height: int
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, height: _Optional[int] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AllDowntimeInfo(_message.Message):
    __slots__ = ("infos",)
    class DowntimeInfo(_message.Message):
        __slots__ = ("duration", "block_info")
        DURATION_FIELD_NUMBER: _ClassVar[int]
        BLOCK_INFO_FIELD_NUMBER: _ClassVar[int]
        duration: _duration_pb2.Duration
        block_info: BlockInfo
        def __init__(self, duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., block_info: _Optional[_Union[BlockInfo, _Mapping]] = ...) -> None: ...
    INFOS_FIELD_NUMBER: _ClassVar[int]
    infos: _containers.RepeatedCompositeFieldContainer[AllDowntimeInfo.DowntimeInfo]
    def __init__(self, infos: _Optional[_Iterable[_Union[AllDowntimeInfo.DowntimeInfo, _Mapping]]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockRateLimitConfiguration(_message.Message):
    __slots__ = ("max_short_term_orders_per_n_blocks", "max_stateful_orders_per_n_blocks", "max_short_term_order_cancellations_per_n_blocks", "max_short_term_orders_and_cancels_per_n_blocks")
    MAX_SHORT_TERM_ORDERS_PER_N_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    MAX_STATEFUL_ORDERS_PER_N_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    MAX_SHORT_TERM_ORDER_CANCELLATIONS_PER_N_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    MAX_SHORT_TERM_ORDERS_AND_CANCELS_PER_N_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    max_short_term_orders_per_n_blocks: _containers.RepeatedCompositeFieldContainer[MaxPerNBlocksRateLimit]
    max_stateful_orders_per_n_blocks: _containers.RepeatedCompositeFieldContainer[MaxPerNBlocksRateLimit]
    max_short_term_order_cancellations_per_n_blocks: _containers.RepeatedCompositeFieldContainer[MaxPerNBlocksRateLimit]
    max_short_term_orders_and_cancels_per_n_blocks: _containers.RepeatedCompositeFieldContainer[MaxPerNBlocksRateLimit]
    def __init__(self, max_short_term_orders_per_n_blocks: _Optional[_Iterable[_Union[MaxPerNBlocksRateLimit, _Mapping]]] = ..., max_stateful_orders_per_n_blocks: _Optional[_Iterable[_Union[MaxPerNBlocksRateLimit, _Mapping]]] = ..., max_short_term_order_cancellations_per_n_blocks: _Optional[_Iterable[_Union[MaxPerNBlocksRateLimit, _Mapping]]] = ..., max_short_term_orders_and_cancels_per_n_blocks: _Optional[_Iterable[_Union[MaxPerNBlocksRateLimit, _Mapping]]] = ...) -> None: ...

class MaxPerNBlocksRateLimit(_message.Message):
    __slots__ = ("num_blocks", "limit")
    NUM_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    num_blocks: int
    limit: int
    def __init__(self, num_blocks: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/bridge/params.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/bridge/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/bridge/params.proto\x12\x13\x64ydxprotocol.bridge\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"G\n\x0b\x45ventParams\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x14\n\x0c\x65th_chain_id\x18\x02 \x01(\x04\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\"\xda\x01\n\rProposeParams\x12\x1d\n\x15max_bridges_per_block\x18\x01 \x01(\r\x12\x43\n\x16propose_delay_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x15\n\rskip_rate_ppm\x18\x03 \x01(\r\x12N\n!skip_if_block_delayed_by_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\"9\n\x0cSafetyParams\x12\x13\n\x0bis_disabled\x18\x01 \x01(\x08\x12\x14\n\x0c\x64\x65lay_blocks\x18\x02 \x01(\rB:Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.bridge.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/types'
  _globals['_PROPOSEPARAMS'].fields_by_name['propose_delay_duration']._loaded_options = None
  _globals['_PROPOSEPARAMS'].fields_by_name['propose_delay_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_PROPOSEPARAMS'].fields_by_name['skip_if_block_delayed_by_duration']._loaded_options = None
  _globals['_PROPOSEPARAMS'].fields_by_name['skip_if_block_delayed_by_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_EVENTPARAMS']._serialized_start=111
  _globals['_EVENTPARAMS']._serialized_end=182
  _globals['_PROPOSEPARAMS']._serialized_start=185
  _globals['_PROPOSEPARAMS']._serialized_end=403
  _globals['_SAFETYPARAMS']._serialized_start=405
  _globals['_SAFETYPARAMS']._serialized_end=462
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Transfer(_message.Message):
    __slots__ = ("sender", "recipient", "asset_id", "amount")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    sender: _subaccount_pb2.SubaccountId
    recipient: _subaccount_pb2.SubaccountId
    asset_id: int
    amount: int
    def __init__(self, sender: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., recipient: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., asset_id: _Optional[int] = ..., amount: _Optional[int] = ...) -> None: ...

class MsgDepositToSubaccount(_message.Message):
    __slots__ = ("sender", "recipient", "asset_id", "quantums")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    sender: str
    recipient: _subaccount_pb2.SubaccountId
    asset_id: int
    quantums: int
    def __init__(self, sender: _Optional[str] = ..., recipient: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., asset_id: _Optional[int] = ..., quantums: _Optional[int] = ...) -> None: ...

class MsgWithdrawFromSubaccount(_message.Message):
    __slots__ = ("sender", "recipient", "asset_id", "quantums")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    sender: _subaccount_pb2.SubaccountId
    recipient: str
    asset_id: int
    quantums: int
    def __init__(self, sender: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., recipient: _Optional[str] = ..., asset_id: _Optional[int] = ..., quantums: _Optional[int] = ...) -> None: ...

class MsgSendFromModuleToAccount(_message.Message):
    __slots__ = ("authority", "sender_module_name", "recipient", "coin")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    SENDER_MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    COIN_FIELD_NUMBER: _ClassVar[int]
    authority: str
    sender_module_name: str
    recipient: str
    coin: _coin_pb2.Coin
    def __init__(self, authority: _Optional[str] = ..., sender_module_name: _Optional[str] = ..., recipient: _Optional[str] = ..., coin: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...



from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PerpetualClobMetadata(_message.Message):
    __slots__ = ("perpetual_id",)
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    def __init__(self, perpetual_id: _Optional[int] = ...) -> None: ...

class SpotClobMetadata(_message.Message):
    __slots__ = ("base_asset_id", "quote_asset_id")
    BASE_ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTE_ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    base_asset_id: int
    quote_asset_id: int
    def __init__(self, base_asset_id: _Optional[int] = ..., quote_asset_id: _Optional[int] = ...) -> None: ...

class ClobPair(_message.Message):
    __slots__ = ("id", "perpetual_clob_metadata", "spot_clob_metadata", "step_base_quantums", "subticks_per_tick", "quantum_conversion_exponent", "status")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATUS_UNSPECIFIED: _ClassVar[ClobPair.Status]
        STATUS_ACTIVE: _ClassVar[ClobPair.Status]
        STATUS_PAUSED: _ClassVar[ClobPair.Status]
        STATUS_CANCEL_ONLY: _ClassVar[ClobPair.Status]
        STATUS_POST_ONLY: _ClassVar[ClobPair.Status]
        STATUS_INITIALIZING: _ClassVar[ClobPair.Status]
        STATUS_FINAL_SETTLEMENT: _ClassVar[ClobPair.Status]
    STATUS_UNSPECIFIED: ClobPair.Status
    STATUS_ACTIVE: ClobPair.Status
    STATUS_PAUSED: ClobPair.Status
    STATUS_CANCEL_ONLY: ClobPair.Status
    STATUS_POST_ONLY: ClobPair.Status
    STATUS_INITIALIZING: ClobPair.Status
    STATUS_FINAL_SETTLEMENT: ClobPair.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_CLOB_METADATA_FIELD_NUMBER: _ClassVar[int]
    SPOT_CLOB_METADATA_FIELD_NUMBER: _ClassVar[int]
    STEP_BASE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_PER_TICK_FIELD_NUMBER: _ClassVar[int]
    QUANTUM_CONVERSION_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: int
    perpetual_clob_metadata: PerpetualClobMetadata
    spot_clob_metadata: SpotClobMetadata
    step_base_quantums: int
    subticks_per_tick: int
    quantum_conversion_exponent: int
    status: ClobPair.Status
    def __init__(self, id: _Optional[int] = ..., perpetual_clob_metadata: _Optional[_Union[PerpetualClobMetadata, _Mapping]] = ..., spot_clob_metadata: _Optional[_Union[SpotClobMetadata, _Mapping]] = ..., step_base_quantums: _Optional[int] = ..., subticks_per_tick: _Optional[int] = ..., quantum_conversion_exponent: _Optional[int] = ..., status: _Optional[_Union[ClobPair.Status, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/prices/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/prices/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.prices import market_param_pb2 as dydxprotocol_dot_prices_dot_market__param__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x64ydxprotocol/prices/tx.proto\x12\x13\x64ydxprotocol.prices\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a&dydxprotocol/prices/market_param.proto\"\x8c\x01\n\x15MsgCreateOracleMarket\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .dydxprotocol.prices.MarketParamB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1f\n\x1dMsgCreateOracleMarketResponse\"\x9e\x01\n\x15MsgUpdateMarketPrices\x12T\n\x14market_price_updates\x18\x01 \x03(\x0b\x32\x36.dydxprotocol.prices.MsgUpdateMarketPrices.MarketPrice\x1a/\n\x0bMarketPrice\x12\x11\n\tmarket_id\x18\x01 \x01(\r\x12\r\n\x05price\x18\x02 \x01(\x04\"\x1f\n\x1dMsgUpdateMarketPricesResponse\"\x91\x01\n\x14MsgUpdateMarketParam\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x0cmarket_param\x18\x02 \x01(\x0b\x32 .dydxprotocol.prices.MarketParamB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgUpdateMarketParamResponse2\xe4\x02\n\x03Msg\x12t\n\x12UpdateMarketPrices\x12*.dydxprotocol.prices.MsgUpdateMarketPrices\x1a\x32.dydxprotocol.prices.MsgUpdateMarketPricesResponse\x12t\n\x12\x43reateOracleMarket\x12*.dydxprotocol.prices.MsgCreateOracleMarket\x1a\x32.dydxprotocol.prices.MsgCreateOracleMarketResponse\x12q\n\x11UpdateMarketParam\x12).dydxprotocol.prices.MsgUpdateMarketParam\x1a\x31.dydxprotocol.prices.MsgUpdateMarketParamResponseB:Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.prices.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/prices/types'
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['params']._loaded_options = None
  _globals['_MSGCREATEORACLEMARKET'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEORACLEMARKET']._loaded_options = None
  _globals['_MSGCREATEORACLEMARKET']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['market_param']._loaded_options = None
  _globals['_MSGUPDATEMARKETPARAM'].fields_by_name['market_param']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEMARKETPARAM']._loaded_options = None
  _globals['_MSGUPDATEMARKETPARAM']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCREATEORACLEMARKET']._serialized_start=168
  _globals['_MSGCREATEORACLEMARKET']._serialized_end=308
  _globals['_MSGCREATEORACLEMARKETRESPONSE']._serialized_start=310
  _globals['_MSGCREATEORACLEMARKETRESPONSE']._serialized_end=341
  _globals['_MSGUPDATEMARKETPRICES']._serialized_start=344
  _globals['_MSGUPDATEMARKETPRICES']._serialized_end=502
  _globals['_MSGUPDATEMARKETPRICES_MARKETPRICE']._serialized_start=455
  _globals['_MSGUPDATEMARKETPRICES_MARKETPRICE']._serialized_end=502
  _globals['_MSGUPDATEMARKETPRICESRESPONSE']._serialized_start=504
  _globals['_MSGUPDATEMARKETPRICESRESPONSE']._serialized_end=535
  _globals['_MSGUPDATEMARKETPARAM']._serialized_start=538
  _globals['_MSGUPDATEMARKETPARAM']._serialized_end=683
  _globals['_MSGUPDATEMARKETPARAMRESPONSE']._serialized_start=685
  _globals['_MSGUPDATEMARKETPARAMRESPONSE']._serialized_end=715
  _globals['_MSG']._serialized_start=718
  _globals['_MSG']._serialized_end=1074
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.gov.v1 import gov_pb2 as _gov_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryConstitutionRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryConstitutionResponse(_message.Message):
    __slots__ = ("constitution",)
    CONSTITUTION_FIELD_NUMBER: _ClassVar[int]
    constitution: str
    def __init__(self, constitution: _Optional[str] = ...) -> None: ...

class QueryProposalRequest(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class QueryProposalResponse(_message.Message):
    __slots__ = ("proposal",)
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    proposal: _gov_pb2.Proposal
    def __init__(self, proposal: _Optional[_Union[_gov_pb2.Proposal, _Mapping]] = ...) -> None: ...

class QueryProposalsRequest(_message.Message):
    __slots__ = ("proposal_status", "voter", "depositor", "pagination")
    PROPOSAL_STATUS_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    proposal_status: _gov_pb2.ProposalStatus
    voter: str
    depositor: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, proposal_status: _Optional[_Union[_gov_pb2.ProposalStatus, str]] = ..., voter: _Optional[str] = ..., depositor: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryProposalsResponse(_message.Message):
    __slots__ = ("proposals", "pagination")
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    proposals: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Proposal]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, proposals: _Optional[_Iterable[_Union[_gov_pb2.Proposal, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryVoteRequest(_message.Message):
    __slots__ = ("proposal_id", "voter")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ...) -> None: ...

class QueryVoteResponse(_message.Message):
    __slots__ = ("vote",)
    VOTE_FIELD_NUMBER: _ClassVar[int]
    vote: _gov_pb2.Vote
    def __init__(self, vote: _Optional[_Union[_gov_pb2.Vote, _Mapping]] = ...) -> None: ...

class QueryVotesRequest(_message.Message):
    __slots__ = ("proposal_id", "pagination")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, proposal_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryVotesResponse(_message.Message):
    __slots__ = ("votes", "pagination")
    VOTES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    votes: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Vote]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, votes: _Optional[_Iterable[_Union[_gov_pb2.Vote, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = ("params_type",)
    PARAMS_TYPE_FIELD_NUMBER: _ClassVar[int]
    params_type: str
    def __init__(self, params_type: _Optional[str] = ...) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("voting_params", "deposit_params", "tally_params", "params")
    VOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    TALLY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    voting_params: _gov_pb2.VotingParams
    deposit_params: _gov_pb2.DepositParams
    tally_params: _gov_pb2.TallyParams
    params: _gov_pb2.Params
    def __init__(self, voting_params: _Optional[_Union[_gov_pb2.VotingParams, _Mapping]] = ..., deposit_params: _Optional[_Union[_gov_pb2.DepositParams, _Mapping]] = ..., tally_params: _Optional[_Union[_gov_pb2.TallyParams, _Mapping]] = ..., params: _Optional[_Union[_gov_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryDepositRequest(_message.Message):
    __slots__ = ("proposal_id", "depositor")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    depositor: str
    def __init__(self, proposal_id: _Optional[int] = ..., depositor: _Optional[str] = ...) -> None: ...

class QueryDepositResponse(_message.Message):
    __slots__ = ("deposit",)
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    deposit: _gov_pb2.Deposit
    def __init__(self, deposit: _Optional[_Union[_gov_pb2.Deposit, _Mapping]] = ...) -> None: ...

class QueryDepositsRequest(_message.Message):
    __slots__ = ("proposal_id", "pagination")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, proposal_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDepositsResponse(_message.Message):
    __slots__ = ("deposits", "pagination")
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    deposits: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Deposit]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, deposits: _Optional[_Iterable[_Union[_gov_pb2.Deposit, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryTallyResultRequest(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class QueryTallyResultResponse(_message.Message):
    __slots__ = ("tally",)
    TALLY_FIELD_NUMBER: _ClassVar[int]
    tally: _gov_pb2.TallyResult
    def __init__(self, tally: _Optional[_Union[_gov_pb2.TallyResult, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("send_enabled", "default_send_enabled")
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    send_enabled: _containers.RepeatedCompositeFieldContainer[SendEnabled]
    default_send_enabled: bool
    def __init__(self, send_enabled: _Optional[_Iterable[_Union[SendEnabled, _Mapping]]] = ..., default_send_enabled: bool = ...) -> None: ...

class SendEnabled(_message.Message):
    __slots__ = ("denom", "enabled")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    denom: str
    enabled: bool
    def __init__(self, denom: _Optional[str] = ..., enabled: bool = ...) -> None: ...

class Input(_message.Message):
    __slots__ = ("address", "coins")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, address: _Optional[str] = ..., coins: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class Output(_message.Message):
    __slots__ = ("address", "coins")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COINS_FIELD_NUMBER: _ClassVar[int]
    address: str
    coins: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, address: _Optional[str] = ..., coins: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class Supply(_message.Message):
    __slots__ = ("total",)
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    total: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, total: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class DenomUnit(_message.Message):
    __slots__ = ("denom", "exponent", "aliases")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    EXPONENT_FIELD_NUMBER: _ClassVar[int]
    ALIASES_FIELD_NUMBER: _ClassVar[int]
    denom: str
    exponent: int
    aliases: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, denom: _Optional[str] = ..., exponent: _Optional[int] = ..., aliases: _Optional[_Iterable[str]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("description", "denom_units", "base", "display", "name", "symbol", "uri", "uri_hash")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DENOM_UNITS_FIELD_NUMBER: _ClassVar[int]
    BASE_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    URI_FIELD_NUMBER: _ClassVar[int]
    URI_HASH_FIELD_NUMBER: _ClassVar[int]
    description: str
    denom_units: _containers.RepeatedCompositeFieldContainer[DenomUnit]
    base: str
    display: str
    name: str
    symbol: str
    uri: str
    uri_hash: str
    def __init__(self, description: _Optional[str] = ..., denom_units: _Optional[_Iterable[_Union[DenomUnit, _Mapping]]] = ..., base: _Optional[str] = ..., display: _Optional[str] = ..., name: _Optional[str] = ..., symbol: _Optional[str] = ..., uri: _Optional[str] = ..., uri_hash: _Optional[str] = ...) -> None: ...



from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.upgrade.v1beta1 import upgrade_pb2 as _upgrade_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryCurrentPlanRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryCurrentPlanResponse(_message.Message):
    __slots__ = ("plan",)
    PLAN_FIELD_NUMBER: _ClassVar[int]
    plan: _upgrade_pb2.Plan
    def __init__(self, plan: _Optional[_Union[_upgrade_pb2.Plan, _Mapping]] = ...) -> None: ...

class QueryAppliedPlanRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class QueryAppliedPlanResponse(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class QueryUpgradedConsensusStateRequest(_message.Message):
    __slots__ = ("last_height",)
    LAST_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    last_height: int
    def __init__(self, last_height: _Optional[int] = ...) -> None: ...

class QueryUpgradedConsensusStateResponse(_message.Message):
    __slots__ = ("upgraded_consensus_state",)
    UPGRADED_CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    upgraded_consensus_state: bytes
    def __init__(self, upgraded_consensus_state: _Optional[bytes] = ...) -> None: ...

class QueryModuleVersionsRequest(_message.Message):
    __slots__ = ("module_name",)
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    module_name: str
    def __init__(self, module_name: _Optional[str] = ...) -> None: ...

class QueryModuleVersionsResponse(_message.Message):
    __slots__ = ("module_versions",)
    MODULE_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    module_versions: _containers.RepeatedCompositeFieldContainer[_upgrade_pb2.ModuleVersion]
    def __init__(self, module_versions: _Optional[_Iterable[_Union[_upgrade_pb2.ModuleVersion, _Mapping]]] = ...) -> None: ...

class QueryAuthorityRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryAuthorityResponse(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/types/block.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'tendermint/types/block.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from v4_proto.tendermint.types import evidence_pb2 as tendermint_dot_types_dot_evidence__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/types/block.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a\x1ftendermint/types/evidence.proto\"\xca\x01\n\x05\x42lock\x12.\n\x06header\x18\x01 \x01(\x0b\x32\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.tendermint.types.DataB\x04\xc8\xde\x1f\x00\x12\x36\n\x08\x65vidence\x18\x03 \x01(\x0b\x32\x1e.tendermint.types.EvidenceListB\x04\xc8\xde\x1f\x00\x12-\n\x0blast_commit\x18\x04 \x01(\x0b\x32\x18.tendermint.types.CommitB5Z3github.com/cometbft/cometbft/proto/tendermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.block_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/cometbft/cometbft/proto/tendermint/types'
  _globals['_BLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK'].fields_by_name['data']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK'].fields_by_name['evidence']._loaded_options = None
  _globals['_BLOCK'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCK']._serialized_start=136
  _globals['_BLOCK']._serialized_end=338
# @@protoc_insertion_point(module_scope)



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.tendermint.types import types_pb2 as _types_pb2
from v4_proto.tendermint.types import evidence_pb2 as _evidence_pb2
from v4_proto.tendermint.version import types_pb2 as _types_pb2_1
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Block(_message.Message):
    __slots__ = ("header", "data", "evidence", "last_commit")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    header: Header
    data: _types_pb2.Data
    evidence: _evidence_pb2.EvidenceList
    last_commit: _types_pb2.Commit
    def __init__(self, header: _Optional[_Union[Header, _Mapping]] = ..., data: _Optional[_Union[_types_pb2.Data, _Mapping]] = ..., evidence: _Optional[_Union[_evidence_pb2.EvidenceList, _Mapping]] = ..., last_commit: _Optional[_Union[_types_pb2.Commit, _Mapping]] = ...) -> None: ...

class Header(_message.Message):
    __slots__ = ("version", "chain_id", "height", "time", "last_block_id", "last_commit_hash", "data_hash", "validators_hash", "next_validators_hash", "consensus_hash", "app_hash", "last_results_hash", "evidence_hash", "proposer_address")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_HASH_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_HASH_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    LAST_RESULTS_HASH_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_HASH_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    version: _types_pb2_1.Consensus
    chain_id: str
    height: int
    time: _timestamp_pb2.Timestamp
    last_block_id: _types_pb2.BlockID
    last_commit_hash: bytes
    data_hash: bytes
    validators_hash: bytes
    next_validators_hash: bytes
    consensus_hash: bytes
    app_hash: bytes
    last_results_hash: bytes
    evidence_hash: bytes
    proposer_address: str
    def __init__(self, version: _Optional[_Union[_types_pb2_1.Consensus, _Mapping]] = ..., chain_id: _Optional[str] = ..., height: _Optional[int] = ..., time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_block_id: _Optional[_Union[_types_pb2.BlockID, _Mapping]] = ..., last_commit_hash: _Optional[bytes] = ..., data_hash: _Optional[bytes] = ..., validators_hash: _Optional[bytes] = ..., next_validators_hash: _Optional[bytes] = ..., consensus_hash: _Optional[bytes] = ..., app_hash: _Optional[bytes] = ..., last_results_hash: _Optional[bytes] = ..., evidence_hash: _Optional[bytes] = ..., proposer_address: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.accountplus import tx_pb2 as dydxprotocol_dot_accountplus_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/accountplus/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddAuthenticator = channel.unary_unary(
                '/dydxprotocol.accountplus.Msg/AddAuthenticator',
                request_serializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgAddAuthenticator.SerializeToString,
                response_deserializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgAddAuthenticatorResponse.FromString,
                _registered_method=True)
        self.RemoveAuthenticator = channel.unary_unary(
                '/dydxprotocol.accountplus.Msg/RemoveAuthenticator',
                request_serializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgRemoveAuthenticator.SerializeToString,
                response_deserializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgRemoveAuthenticatorResponse.FromString,
                _registered_method=True)
        self.SetActiveState = channel.unary_unary(
                '/dydxprotocol.accountplus.Msg/SetActiveState',
                request_serializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgSetActiveState.SerializeToString,
                response_deserializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgSetActiveStateResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def AddAuthenticator(self, request, context):
        """AddAuthenticator adds an authenticator to an account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAuthenticator(self, request, context):
        """RemoveAuthenticator removes an authenticator from an account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetActiveState(self, request, context):
        """SetActiveState sets the active state of the authenticator.
        Primarily used for circuit breaking.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddAuthenticator': grpc.unary_unary_rpc_method_handler(
                    servicer.AddAuthenticator,
                    request_deserializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgAddAuthenticator.FromString,
                    response_serializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgAddAuthenticatorResponse.SerializeToString,
            ),
            'RemoveAuthenticator': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAuthenticator,
                    request_deserializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgRemoveAuthenticator.FromString,
                    response_serializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgRemoveAuthenticatorResponse.SerializeToString,
            ),
            'SetActiveState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetActiveState,
                    request_deserializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgSetActiveState.FromString,
                    response_serializer=dydxprotocol_dot_accountplus_dot_tx__pb2.MsgSetActiveStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.accountplus.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.accountplus.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def AddAuthenticator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.accountplus.Msg/AddAuthenticator',
            dydxprotocol_dot_accountplus_dot_tx__pb2.MsgAddAuthenticator.SerializeToString,
            dydxprotocol_dot_accountplus_dot_tx__pb2.MsgAddAuthenticatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveAuthenticator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.accountplus.Msg/RemoveAuthenticator',
            dydxprotocol_dot_accountplus_dot_tx__pb2.MsgRemoveAuthenticator.SerializeToString,
            dydxprotocol_dot_accountplus_dot_tx__pb2.MsgRemoveAuthenticatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetActiveState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.accountplus.Msg/SetActiveState',
            dydxprotocol_dot_accountplus_dot_tx__pb2.MsgSetActiveState.SerializeToString,
            dydxprotocol_dot_accountplus_dot_tx__pb2.MsgSetActiveStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/keyring/v1/record.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crypto/keyring/v1/record.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.cosmos.crypto.hd.v1 import hd_pb2 as cosmos_dot_crypto_dot_hd_dot_v1_dot_hd__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/crypto/keyring/v1/record.proto\x12\x18\x63osmos.crypto.keyring.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1c\x63osmos/crypto/hd/v1/hd.proto\"\xae\x03\n\x06Record\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x37\n\x05local\x18\x03 \x01(\x0b\x32&.cosmos.crypto.keyring.v1.Record.LocalH\x00\x12\x39\n\x06ledger\x18\x04 \x01(\x0b\x32\'.cosmos.crypto.keyring.v1.Record.LedgerH\x00\x12\x37\n\x05multi\x18\x05 \x01(\x0b\x32&.cosmos.crypto.keyring.v1.Record.MultiH\x00\x12;\n\x07offline\x18\x06 \x01(\x0b\x32(.cosmos.crypto.keyring.v1.Record.OfflineH\x00\x1a/\n\x05Local\x12&\n\x08priv_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x1a\x38\n\x06Ledger\x12.\n\x04path\x18\x01 \x01(\x0b\x32 .cosmos.crypto.hd.v1.BIP44Params\x1a\x07\n\x05Multi\x1a\t\n\x07OfflineB\x06\n\x04itemB5Z+github.com/cosmos/cosmos-sdk/crypto/keyring\xc8\xe1\x1e\x00\x98\xe3\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.keyring.v1.record_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/crypto/keyring\310\341\036\000\230\343\036\000'
  _globals['_RECORD']._serialized_start=147
  _globals['_RECORD']._serialized_end=577
  _globals['_RECORD_LOCAL']._serialized_start=444
  _globals['_RECORD_LOCAL']._serialized_end=491
  _globals['_RECORD_LEDGER']._serialized_start=493
  _globals['_RECORD_LEDGER']._serialized_end=549
  _globals['_RECORD_MULTI']._serialized_start=551
  _globals['_RECORD_MULTI']._serialized_end=558
  _globals['_RECORD_OFFLINE']._serialized_start=560
  _globals['_RECORD_OFFLINE']._serialized_end=569
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/perpetuals/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/perpetuals/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as dydxprotocol_dot_perpetuals_dot_params__pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as dydxprotocol_dot_perpetuals_dot_perpetual__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/perpetuals/query.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a$dydxprotocol/perpetuals/params.proto\x1a\'dydxprotocol/perpetuals/perpetual.proto\"#\n\x15QueryPerpetualRequest\x12\n\n\x02id\x18\x01 \x01(\r\"U\n\x16QueryPerpetualResponse\x12;\n\tperpetual\x18\x01 \x01(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\"W\n\x19QueryAllPerpetualsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1aQueryAllPerpetualsResponse\x12;\n\tperpetual\x18\x01 \x03(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"[\n\x1dQueryAllLiquidityTiersRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xa4\x01\n\x1eQueryAllLiquidityTiersResponse\x12\x45\n\x0fliquidity_tiers\x18\x01 \x03(\x0b\x32&.dydxprotocol.perpetuals.LiquidityTierB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x1a\n\x18QueryPremiumVotesRequest\"_\n\x19QueryPremiumVotesResponse\x12\x42\n\rpremium_votes\x18\x01 \x01(\x0b\x32%.dydxprotocol.perpetuals.PremiumStoreB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aQueryPremiumSamplesRequest\"c\n\x1bQueryPremiumSamplesResponse\x12\x44\n\x0fpremium_samples\x18\x01 \x01(\x0b\x32%.dydxprotocol.perpetuals.PremiumStoreB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"L\n\x13QueryParamsResponse\x12\x35\n\x06params\x18\x01 \x01(\x0b\x32\x1f.dydxprotocol.perpetuals.ParamsB\x04\xc8\xde\x1f\x00\"\x1d\n\x1bQueryNextPerpetualIdRequest\"9\n\x1cQueryNextPerpetualIdResponse\x12\x19\n\x11next_perpetual_id\x18\x01 \x01(\r2\xa3\t\n\x05Query\x12\x9d\x01\n\tPerpetual\x12..dydxprotocol.perpetuals.QueryPerpetualRequest\x1a/.dydxprotocol.perpetuals.QueryPerpetualResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dydxprotocol/perpetuals/perpetual/{id}\x12\xa4\x01\n\rAllPerpetuals\x12\x32.dydxprotocol.perpetuals.QueryAllPerpetualsRequest\x1a\x33.dydxprotocol.perpetuals.QueryAllPerpetualsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/dydxprotocol/perpetuals/perpetual\x12\xb6\x01\n\x11\x41llLiquidityTiers\x12\x36.dydxprotocol.perpetuals.QueryAllLiquidityTiersRequest\x1a\x37.dydxprotocol.perpetuals.QueryAllLiquidityTiersResponse\"0\x82\xd3\xe4\x93\x02*\x12(/dydxprotocol/perpetuals/liquidity_tiers\x12\xa5\x01\n\x0cPremiumVotes\x12\x31.dydxprotocol.perpetuals.QueryPremiumVotesRequest\x1a\x32.dydxprotocol.perpetuals.QueryPremiumVotesResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/perpetuals/premium_votes\x12\xad\x01\n\x0ePremiumSamples\x12\x33.dydxprotocol.perpetuals.QueryPremiumSamplesRequest\x1a\x34.dydxprotocol.perpetuals.QueryPremiumSamplesResponse\"0\x82\xd3\xe4\x93\x02*\x12(/dydxprotocol/perpetuals/premium_samples\x12\x8c\x01\n\x06Params\x12+.dydxprotocol.perpetuals.QueryParamsRequest\x1a,.dydxprotocol.perpetuals.QueryParamsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/dydxprotocol/perpetuals/params\x12\xb2\x01\n\x0fNextPerpetualId\x12\x34.dydxprotocol.perpetuals.QueryNextPerpetualIdRequest\x1a\x35.dydxprotocol.perpetuals.QueryNextPerpetualIdResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/perpetuals/next_perpetual_idB>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_QUERYPERPETUALRESPONSE'].fields_by_name['perpetual']._loaded_options = None
  _globals['_QUERYPERPETUALRESPONSE'].fields_by_name['perpetual']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLPERPETUALSRESPONSE'].fields_by_name['perpetual']._loaded_options = None
  _globals['_QUERYALLPERPETUALSRESPONSE'].fields_by_name['perpetual']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYALLLIQUIDITYTIERSRESPONSE'].fields_by_name['liquidity_tiers']._loaded_options = None
  _globals['_QUERYALLLIQUIDITYTIERSRESPONSE'].fields_by_name['liquidity_tiers']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPREMIUMVOTESRESPONSE'].fields_by_name['premium_votes']._loaded_options = None
  _globals['_QUERYPREMIUMVOTESRESPONSE'].fields_by_name['premium_votes']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPREMIUMSAMPLESRESPONSE'].fields_by_name['premium_samples']._loaded_options = None
  _globals['_QUERYPREMIUMSAMPLESRESPONSE'].fields_by_name['premium_samples']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Perpetual']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Perpetual']._serialized_options = b'\202\323\344\223\002)\022\'/dydxprotocol/perpetuals/perpetual/{id}'
  _globals['_QUERY'].methods_by_name['AllPerpetuals']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllPerpetuals']._serialized_options = b'\202\323\344\223\002$\022\"/dydxprotocol/perpetuals/perpetual'
  _globals['_QUERY'].methods_by_name['AllLiquidityTiers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllLiquidityTiers']._serialized_options = b'\202\323\344\223\002*\022(/dydxprotocol/perpetuals/liquidity_tiers'
  _globals['_QUERY'].methods_by_name['PremiumVotes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PremiumVotes']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/perpetuals/premium_votes'
  _globals['_QUERY'].methods_by_name['PremiumSamples']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PremiumSamples']._serialized_options = b'\202\323\344\223\002*\022(/dydxprotocol/perpetuals/premium_samples'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002!\022\037/dydxprotocol/perpetuals/params'
  _globals['_QUERY'].methods_by_name['NextPerpetualId']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NextPerpetualId']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/perpetuals/next_perpetual_id'
  _globals['_QUERYPERPETUALREQUEST']._serialized_start=239
  _globals['_QUERYPERPETUALREQUEST']._serialized_end=274
  _globals['_QUERYPERPETUALRESPONSE']._serialized_start=276
  _globals['_QUERYPERPETUALRESPONSE']._serialized_end=361
  _globals['_QUERYALLPERPETUALSREQUEST']._serialized_start=363
  _globals['_QUERYALLPERPETUALSREQUEST']._serialized_end=450
  _globals['_QUERYALLPERPETUALSRESPONSE']._serialized_start=453
  _globals['_QUERYALLPERPETUALSRESPONSE']._serialized_end=603
  _globals['_QUERYALLLIQUIDITYTIERSREQUEST']._serialized_start=605
  _globals['_QUERYALLLIQUIDITYTIERSREQUEST']._serialized_end=696
  _globals['_QUERYALLLIQUIDITYTIERSRESPONSE']._serialized_start=699
  _globals['_QUERYALLLIQUIDITYTIERSRESPONSE']._serialized_end=863
  _globals['_QUERYPREMIUMVOTESREQUEST']._serialized_start=865
  _globals['_QUERYPREMIUMVOTESREQUEST']._serialized_end=891
  _globals['_QUERYPREMIUMVOTESRESPONSE']._serialized_start=893
  _globals['_QUERYPREMIUMVOTESRESPONSE']._serialized_end=988
  _globals['_QUERYPREMIUMSAMPLESREQUEST']._serialized_start=990
  _globals['_QUERYPREMIUMSAMPLESREQUEST']._serialized_end=1018
  _globals['_QUERYPREMIUMSAMPLESRESPONSE']._serialized_start=1020
  _globals['_QUERYPREMIUMSAMPLESRESPONSE']._serialized_end=1119
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1121
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1141
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1143
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1219
  _globals['_QUERYNEXTPERPETUALIDREQUEST']._serialized_start=1221
  _globals['_QUERYNEXTPERPETUALIDREQUEST']._serialized_end=1250
  _globals['_QUERYNEXTPERPETUALIDRESPONSE']._serialized_start=1252
  _globals['_QUERYNEXTPERPETUALIDRESPONSE']._serialized_end=1309
  _globals['_QUERY']._serialized_start=1312
  _globals['_QUERY']._serialized_end=2499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/epochs/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/epochs/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.epochs import epoch_info_pb2 as dydxprotocol_dot_epochs_dot_epoch__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/epochs/query.proto\x12\x13\x64ydxprotocol.epochs\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a$dydxprotocol/epochs/epoch_info.proto\"(\n\x18QueryGetEpochInfoRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"R\n\x16QueryEpochInfoResponse\x12\x38\n\nepoch_info\x18\x01 \x01(\x0b\x32\x1e.dydxprotocol.epochs.EpochInfoB\x04\xc8\xde\x1f\x00\"V\n\x18QueryAllEpochInfoRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x92\x01\n\x19QueryEpochInfoAllResponse\x12\x38\n\nepoch_info\x18\x01 \x03(\x0b\x32\x1e.dydxprotocol.epochs.EpochInfoB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xc0\x02\n\x05Query\x12\x9a\x01\n\tEpochInfo\x12-.dydxprotocol.epochs.QueryGetEpochInfoRequest\x1a+.dydxprotocol.epochs.QueryEpochInfoResponse\"1\x82\xd3\xe4\x93\x02+\x12)/dydxprotocol/v4/epochs/epoch_info/{name}\x12\x99\x01\n\x0c\x45pochInfoAll\x12-.dydxprotocol.epochs.QueryAllEpochInfoRequest\x1a..dydxprotocol.epochs.QueryEpochInfoAllResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/dydxprotocol/v4/epochs/epoch_infoB:Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.epochs.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/types'
  _globals['_QUERYEPOCHINFORESPONSE'].fields_by_name['epoch_info']._loaded_options = None
  _globals['_QUERYEPOCHINFORESPONSE'].fields_by_name['epoch_info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYEPOCHINFOALLRESPONSE'].fields_by_name['epoch_info']._loaded_options = None
  _globals['_QUERYEPOCHINFOALLRESPONSE'].fields_by_name['epoch_info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['EpochInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EpochInfo']._serialized_options = b'\202\323\344\223\002+\022)/dydxprotocol/v4/epochs/epoch_info/{name}'
  _globals['_QUERY'].methods_by_name['EpochInfoAll']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EpochInfoAll']._serialized_options = b'\202\323\344\223\002$\022\"/dydxprotocol/v4/epochs/epoch_info'
  _globals['_QUERYGETEPOCHINFOREQUEST']._serialized_start=190
  _globals['_QUERYGETEPOCHINFOREQUEST']._serialized_end=230
  _globals['_QUERYEPOCHINFORESPONSE']._serialized_start=232
  _globals['_QUERYEPOCHINFORESPONSE']._serialized_end=314
  _globals['_QUERYALLEPOCHINFOREQUEST']._serialized_start=316
  _globals['_QUERYALLEPOCHINFOREQUEST']._serialized_end=402
  _globals['_QUERYEPOCHINFOALLRESPONSE']._serialized_start=405
  _globals['_QUERYEPOCHINFOALLRESPONSE']._serialized_end=551
  _globals['_QUERY']._serialized_start=554
  _globals['_QUERY']._serialized_end=874
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/feegrant/v1beta1/feegrant.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/feegrant/v1beta1/feegrant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/feegrant/v1beta1/feegrant.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x87\x02\n\x0e\x42\x61sicAllowance\x12v\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12\x34\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01:G\xca\xb4-%cosmos.feegrant.v1beta1.FeeAllowanceI\x8a\xe7\xb0*\x19\x63osmos-sdk/BasicAllowance\"\x99\x04\n\x11PeriodicAllowance\x12\x41\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\'.cosmos.feegrant.v1beta1.BasicAllowanceB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x38\n\x06period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12}\n\x12period_spend_limit\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12{\n\x10period_can_spend\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12?\n\x0cperiod_reset\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01:J\xca\xb4-%cosmos.feegrant.v1beta1.FeeAllowanceI\x8a\xe7\xb0*\x1c\x63osmos-sdk/PeriodicAllowance\"\xd5\x01\n\x13\x41llowedMsgAllowance\x12R\n\tallowance\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB)\xca\xb4-%cosmos.feegrant.v1beta1.FeeAllowanceI\x12\x18\n\x10\x61llowed_messages\x18\x02 \x03(\t:P\x88\xa0\x1f\x00\xca\xb4-%cosmos.feegrant.v1beta1.FeeAllowanceI\x8a\xe7\xb0*\x1e\x63osmos-sdk/AllowedMsgAllowance\"\xb1\x01\n\x05Grant\x12)\n\x07granter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12R\n\tallowance\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB)\xca\xb4-%cosmos.feegrant.v1beta1.FeeAllowanceIB\x19Z\x17\x63osmossdk.io/x/feegrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.v1beta1.feegrant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027cosmossdk.io/x/feegrant'
  _globals['_BASICALLOWANCE'].fields_by_name['spend_limit']._loaded_options = None
  _globals['_BASICALLOWANCE'].fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_BASICALLOWANCE'].fields_by_name['expiration']._loaded_options = None
  _globals['_BASICALLOWANCE'].fields_by_name['expiration']._serialized_options = b'\220\337\037\001'
  _globals['_BASICALLOWANCE']._loaded_options = None
  _globals['_BASICALLOWANCE']._serialized_options = b'\312\264-%cosmos.feegrant.v1beta1.FeeAllowanceI\212\347\260*\031cosmos-sdk/BasicAllowance'
  _globals['_PERIODICALLOWANCE'].fields_by_name['basic']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['basic']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_spend_limit']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_can_spend']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_can_spend']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_reset']._loaded_options = None
  _globals['_PERIODICALLOWANCE'].fields_by_name['period_reset']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PERIODICALLOWANCE']._loaded_options = None
  _globals['_PERIODICALLOWANCE']._serialized_options = b'\312\264-%cosmos.feegrant.v1beta1.FeeAllowanceI\212\347\260*\034cosmos-sdk/PeriodicAllowance'
  _globals['_ALLOWEDMSGALLOWANCE'].fields_by_name['allowance']._loaded_options = None
  _globals['_ALLOWEDMSGALLOWANCE'].fields_by_name['allowance']._serialized_options = b'\312\264-%cosmos.feegrant.v1beta1.FeeAllowanceI'
  _globals['_ALLOWEDMSGALLOWANCE']._loaded_options = None
  _globals['_ALLOWEDMSGALLOWANCE']._serialized_options = b'\210\240\037\000\312\264-%cosmos.feegrant.v1beta1.FeeAllowanceI\212\347\260*\036cosmos-sdk/AllowedMsgAllowance'
  _globals['_GRANT'].fields_by_name['granter']._loaded_options = None
  _globals['_GRANT'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_GRANT'].fields_by_name['grantee']._loaded_options = None
  _globals['_GRANT'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_GRANT'].fields_by_name['allowance']._loaded_options = None
  _globals['_GRANT'].fields_by_name['allowance']._serialized_options = b'\312\264-%cosmos.feegrant.v1beta1.FeeAllowanceI'
  _globals['_BASICALLOWANCE']._serialized_start=260
  _globals['_BASICALLOWANCE']._serialized_end=523
  _globals['_PERIODICALLOWANCE']._serialized_start=526
  _globals['_PERIODICALLOWANCE']._serialized_end=1063
  _globals['_ALLOWEDMSGALLOWANCE']._serialized_start=1066
  _globals['_ALLOWEDMSGALLOWANCE']._serialized_end=1279
  _globals['_GRANT']._serialized_start=1282
  _globals['_GRANT']._serialized_end=1459
# @@protoc_insertion_point(module_scope)



from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.tendermint.types import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "block", "evidence", "validator", "abci")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    ABCI_FIELD_NUMBER: _ClassVar[int]
    authority: str
    block: _params_pb2.BlockParams
    evidence: _params_pb2.EvidenceParams
    validator: _params_pb2.ValidatorParams
    abci: _params_pb2.ABCIParams
    def __init__(self, authority: _Optional[str] = ..., block: _Optional[_Union[_params_pb2.BlockParams, _Mapping]] = ..., evidence: _Optional[_Union[_params_pb2.EvidenceParams, _Mapping]] = ..., validator: _Optional[_Union[_params_pb2.ValidatorParams, _Mapping]] = ..., abci: _Optional[_Union[_params_pb2.ABCIParams, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.indexer.shared import removal_reason_pb2 as _removal_reason_pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as _clob_pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import perpetual_pb2 as _perpetual_pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import vault_pb2 as _vault_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FundingUpdateV1(_message.Message):
    __slots__ = ("perpetual_id", "funding_value_ppm", "funding_index")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    FUNDING_VALUE_PPM_FIELD_NUMBER: _ClassVar[int]
    FUNDING_INDEX_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    funding_value_ppm: int
    funding_index: bytes
    def __init__(self, perpetual_id: _Optional[int] = ..., funding_value_ppm: _Optional[int] = ..., funding_index: _Optional[bytes] = ...) -> None: ...

class FundingEventV1(_message.Message):
    __slots__ = ("updates", "type")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TYPE_UNSPECIFIED: _ClassVar[FundingEventV1.Type]
        TYPE_PREMIUM_SAMPLE: _ClassVar[FundingEventV1.Type]
        TYPE_FUNDING_RATE_AND_INDEX: _ClassVar[FundingEventV1.Type]
        TYPE_PREMIUM_VOTE: _ClassVar[FundingEventV1.Type]
    TYPE_UNSPECIFIED: FundingEventV1.Type
    TYPE_PREMIUM_SAMPLE: FundingEventV1.Type
    TYPE_FUNDING_RATE_AND_INDEX: FundingEventV1.Type
    TYPE_PREMIUM_VOTE: FundingEventV1.Type
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    updates: _containers.RepeatedCompositeFieldContainer[FundingUpdateV1]
    type: FundingEventV1.Type
    def __init__(self, updates: _Optional[_Iterable[_Union[FundingUpdateV1, _Mapping]]] = ..., type: _Optional[_Union[FundingEventV1.Type, str]] = ...) -> None: ...

class MarketEventV1(_message.Message):
    __slots__ = ("market_id", "price_update", "market_create", "market_modify")
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    PRICE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    MARKET_CREATE_FIELD_NUMBER: _ClassVar[int]
    MARKET_MODIFY_FIELD_NUMBER: _ClassVar[int]
    market_id: int
    price_update: MarketPriceUpdateEventV1
    market_create: MarketCreateEventV1
    market_modify: MarketModifyEventV1
    def __init__(self, market_id: _Optional[int] = ..., price_update: _Optional[_Union[MarketPriceUpdateEventV1, _Mapping]] = ..., market_create: _Optional[_Union[MarketCreateEventV1, _Mapping]] = ..., market_modify: _Optional[_Union[MarketModifyEventV1, _Mapping]] = ...) -> None: ...

class MarketPriceUpdateEventV1(_message.Message):
    __slots__ = ("price_with_exponent",)
    PRICE_WITH_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    price_with_exponent: int
    def __init__(self, price_with_exponent: _Optional[int] = ...) -> None: ...

class MarketBaseEventV1(_message.Message):
    __slots__ = ("pair", "min_price_change_ppm")
    PAIR_FIELD_NUMBER: _ClassVar[int]
    MIN_PRICE_CHANGE_PPM_FIELD_NUMBER: _ClassVar[int]
    pair: str
    min_price_change_ppm: int
    def __init__(self, pair: _Optional[str] = ..., min_price_change_ppm: _Optional[int] = ...) -> None: ...

class MarketCreateEventV1(_message.Message):
    __slots__ = ("base", "exponent")
    BASE_FIELD_NUMBER: _ClassVar[int]
    EXPONENT_FIELD_NUMBER: _ClassVar[int]
    base: MarketBaseEventV1
    exponent: int
    def __init__(self, base: _Optional[_Union[MarketBaseEventV1, _Mapping]] = ..., exponent: _Optional[int] = ...) -> None: ...

class MarketModifyEventV1(_message.Message):
    __slots__ = ("base",)
    BASE_FIELD_NUMBER: _ClassVar[int]
    base: MarketBaseEventV1
    def __init__(self, base: _Optional[_Union[MarketBaseEventV1, _Mapping]] = ...) -> None: ...

class SourceOfFunds(_message.Message):
    __slots__ = ("subaccount_id", "address")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.IndexerSubaccountId
    address: str
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., address: _Optional[str] = ...) -> None: ...

class TransferEventV1(_message.Message):
    __slots__ = ("sender_subaccount_id", "recipient_subaccount_id", "asset_id", "amount", "sender", "recipient")
    SENDER_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    ASSET_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    sender_subaccount_id: _subaccount_pb2.IndexerSubaccountId
    recipient_subaccount_id: _subaccount_pb2.IndexerSubaccountId
    asset_id: int
    amount: int
    sender: SourceOfFunds
    recipient: SourceOfFunds
    def __init__(self, sender_subaccount_id: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., recipient_subaccount_id: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., asset_id: _Optional[int] = ..., amount: _Optional[int] = ..., sender: _Optional[_Union[SourceOfFunds, _Mapping]] = ..., recipient: _Optional[_Union[SourceOfFunds, _Mapping]] = ...) -> None: ...

class OrderFillEventV1(_message.Message):
    __slots__ = ("maker_order", "order", "liquidation_order", "fill_amount", "maker_fee", "taker_fee", "total_filled_maker", "total_filled_taker", "affiliate_rev_share", "maker_builder_fee", "taker_builder_fee", "maker_builder_address", "taker_builder_address", "maker_order_router_fee", "taker_order_router_fee", "maker_order_router_address", "taker_order_router_address")
    MAKER_ORDER_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    LIQUIDATION_ORDER_FIELD_NUMBER: _ClassVar[int]
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    MAKER_FEE_FIELD_NUMBER: _ClassVar[int]
    TAKER_FEE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FILLED_MAKER_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FILLED_TAKER_FIELD_NUMBER: _ClassVar[int]
    AFFILIATE_REV_SHARE_FIELD_NUMBER: _ClassVar[int]
    MAKER_BUILDER_FEE_FIELD_NUMBER: _ClassVar[int]
    TAKER_BUILDER_FEE_FIELD_NUMBER: _ClassVar[int]
    MAKER_BUILDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TAKER_BUILDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_ROUTER_FEE_FIELD_NUMBER: _ClassVar[int]
    TAKER_ORDER_ROUTER_FEE_FIELD_NUMBER: _ClassVar[int]
    MAKER_ORDER_ROUTER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TAKER_ORDER_ROUTER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    maker_order: _clob_pb2.IndexerOrder
    order: _clob_pb2.IndexerOrder
    liquidation_order: LiquidationOrderV1
    fill_amount: int
    maker_fee: int
    taker_fee: int
    total_filled_maker: int
    total_filled_taker: int
    affiliate_rev_share: int
    maker_builder_fee: int
    taker_builder_fee: int
    maker_builder_address: str
    taker_builder_address: str
    maker_order_router_fee: int
    taker_order_router_fee: int
    maker_order_router_address: str
    taker_order_router_address: str
    def __init__(self, maker_order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ..., order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ..., liquidation_order: _Optional[_Union[LiquidationOrderV1, _Mapping]] = ..., fill_amount: _Optional[int] = ..., maker_fee: _Optional[int] = ..., taker_fee: _Optional[int] = ..., total_filled_maker: _Optional[int] = ..., total_filled_taker: _Optional[int] = ..., affiliate_rev_share: _Optional[int] = ..., maker_builder_fee: _Optional[int] = ..., taker_builder_fee: _Optional[int] = ..., maker_builder_address: _Optional[str] = ..., taker_builder_address: _Optional[str] = ..., maker_order_router_fee: _Optional[int] = ..., taker_order_router_fee: _Optional[int] = ..., maker_order_router_address: _Optional[str] = ..., taker_order_router_address: _Optional[str] = ...) -> None: ...

class DeleveragingEventV1(_message.Message):
    __slots__ = ("liquidated", "offsetting", "perpetual_id", "fill_amount", "total_quote_quantums", "is_buy", "is_final_settlement")
    LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    OFFSETTING_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    IS_BUY_FIELD_NUMBER: _ClassVar[int]
    IS_FINAL_SETTLEMENT_FIELD_NUMBER: _ClassVar[int]
    liquidated: _subaccount_pb2.IndexerSubaccountId
    offsetting: _subaccount_pb2.IndexerSubaccountId
    perpetual_id: int
    fill_amount: int
    total_quote_quantums: int
    is_buy: bool
    is_final_settlement: bool
    def __init__(self, liquidated: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., offsetting: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., perpetual_id: _Optional[int] = ..., fill_amount: _Optional[int] = ..., total_quote_quantums: _Optional[int] = ..., is_buy: bool = ..., is_final_settlement: bool = ...) -> None: ...

class LiquidationOrderV1(_message.Message):
    __slots__ = ("liquidated", "clob_pair_id", "perpetual_id", "total_size", "is_buy", "subticks")
    LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    IS_BUY_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    liquidated: _subaccount_pb2.IndexerSubaccountId
    clob_pair_id: int
    perpetual_id: int
    total_size: int
    is_buy: bool
    subticks: int
    def __init__(self, liquidated: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., clob_pair_id: _Optional[int] = ..., perpetual_id: _Optional[int] = ..., total_size: _Optional[int] = ..., is_buy: bool = ..., subticks: _Optional[int] = ...) -> None: ...

class SubaccountUpdateEventV1(_message.Message):
    __slots__ = ("subaccount_id", "updated_perpetual_positions", "updated_asset_positions")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_PERPETUAL_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    UPDATED_ASSET_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.IndexerSubaccountId
    updated_perpetual_positions: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.IndexerPerpetualPosition]
    updated_asset_positions: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.IndexerAssetPosition]
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., updated_perpetual_positions: _Optional[_Iterable[_Union[_subaccount_pb2.IndexerPerpetualPosition, _Mapping]]] = ..., updated_asset_positions: _Optional[_Iterable[_Union[_subaccount_pb2.IndexerAssetPosition, _Mapping]]] = ...) -> None: ...

class StatefulOrderEventV1(_message.Message):
    __slots__ = ("order_place", "order_removal", "conditional_order_placement", "conditional_order_triggered", "long_term_order_placement", "order_replacement", "twap_order_placement")
    class StatefulOrderPlacementV1(_message.Message):
        __slots__ = ("order",)
        ORDER_FIELD_NUMBER: _ClassVar[int]
        order: _clob_pb2.IndexerOrder
        def __init__(self, order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ...) -> None: ...
    class StatefulOrderRemovalV1(_message.Message):
        __slots__ = ("removed_order_id", "reason")
        REMOVED_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
        REASON_FIELD_NUMBER: _ClassVar[int]
        removed_order_id: _clob_pb2.IndexerOrderId
        reason: _removal_reason_pb2.OrderRemovalReason
        def __init__(self, removed_order_id: _Optional[_Union[_clob_pb2.IndexerOrderId, _Mapping]] = ..., reason: _Optional[_Union[_removal_reason_pb2.OrderRemovalReason, str]] = ...) -> None: ...
    class ConditionalOrderPlacementV1(_message.Message):
        __slots__ = ("order",)
        ORDER_FIELD_NUMBER: _ClassVar[int]
        order: _clob_pb2.IndexerOrder
        def __init__(self, order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ...) -> None: ...
    class ConditionalOrderTriggeredV1(_message.Message):
        __slots__ = ("triggered_order_id",)
        TRIGGERED_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
        triggered_order_id: _clob_pb2.IndexerOrderId
        def __init__(self, triggered_order_id: _Optional[_Union[_clob_pb2.IndexerOrderId, _Mapping]] = ...) -> None: ...
    class LongTermOrderPlacementV1(_message.Message):
        __slots__ = ("order",)
        ORDER_FIELD_NUMBER: _ClassVar[int]
        order: _clob_pb2.IndexerOrder
        def __init__(self, order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ...) -> None: ...
    class LongTermOrderReplacementV1(_message.Message):
        __slots__ = ("old_order_id", "order")
        OLD_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
        ORDER_FIELD_NUMBER: _ClassVar[int]
        old_order_id: _clob_pb2.IndexerOrderId
        order: _clob_pb2.IndexerOrder
        def __init__(self, old_order_id: _Optional[_Union[_clob_pb2.IndexerOrderId, _Mapping]] = ..., order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ...) -> None: ...
    class TwapOrderPlacementV1(_message.Message):
        __slots__ = ("order",)
        ORDER_FIELD_NUMBER: _ClassVar[int]
        order: _clob_pb2.IndexerOrder
        def __init__(self, order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ...) -> None: ...
    ORDER_PLACE_FIELD_NUMBER: _ClassVar[int]
    ORDER_REMOVAL_FIELD_NUMBER: _ClassVar[int]
    CONDITIONAL_ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    CONDITIONAL_ORDER_TRIGGERED_FIELD_NUMBER: _ClassVar[int]
    LONG_TERM_ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    ORDER_REPLACEMENT_FIELD_NUMBER: _ClassVar[int]
    TWAP_ORDER_PLACEMENT_FIELD_NUMBER: _ClassVar[int]
    order_place: StatefulOrderEventV1.StatefulOrderPlacementV1
    order_removal: StatefulOrderEventV1.StatefulOrderRemovalV1
    conditional_order_placement: StatefulOrderEventV1.ConditionalOrderPlacementV1
    conditional_order_triggered: StatefulOrderEventV1.ConditionalOrderTriggeredV1
    long_term_order_placement: StatefulOrderEventV1.LongTermOrderPlacementV1
    order_replacement: StatefulOrderEventV1.LongTermOrderReplacementV1
    twap_order_placement: StatefulOrderEventV1.TwapOrderPlacementV1
    def __init__(self, order_place: _Optional[_Union[StatefulOrderEventV1.StatefulOrderPlacementV1, _Mapping]] = ..., order_removal: _Optional[_Union[StatefulOrderEventV1.StatefulOrderRemovalV1, _Mapping]] = ..., conditional_order_placement: _Optional[_Union[StatefulOrderEventV1.ConditionalOrderPlacementV1, _Mapping]] = ..., conditional_order_triggered: _Optional[_Union[StatefulOrderEventV1.ConditionalOrderTriggeredV1, _Mapping]] = ..., long_term_order_placement: _Optional[_Union[StatefulOrderEventV1.LongTermOrderPlacementV1, _Mapping]] = ..., order_replacement: _Optional[_Union[StatefulOrderEventV1.LongTermOrderReplacementV1, _Mapping]] = ..., twap_order_placement: _Optional[_Union[StatefulOrderEventV1.TwapOrderPlacementV1, _Mapping]] = ...) -> None: ...

class AssetCreateEventV1(_message.Message):
    __slots__ = ("id", "symbol", "has_market", "market_id", "atomic_resolution")
    ID_FIELD_NUMBER: _ClassVar[int]
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    HAS_MARKET_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    symbol: str
    has_market: bool
    market_id: int
    atomic_resolution: int
    def __init__(self, id: _Optional[int] = ..., symbol: _Optional[str] = ..., has_market: bool = ..., market_id: _Optional[int] = ..., atomic_resolution: _Optional[int] = ...) -> None: ...

class PerpetualMarketCreateEventV1(_message.Message):
    __slots__ = ("id", "clob_pair_id", "ticker", "market_id", "status", "quantum_conversion_exponent", "atomic_resolution", "subticks_per_tick", "step_base_quantums", "liquidity_tier")
    ID_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    QUANTUM_CONVERSION_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_PER_TICK_FIELD_NUMBER: _ClassVar[int]
    STEP_BASE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    id: int
    clob_pair_id: int
    ticker: str
    market_id: int
    status: _clob_pb2.ClobPairStatus
    quantum_conversion_exponent: int
    atomic_resolution: int
    subticks_per_tick: int
    step_base_quantums: int
    liquidity_tier: int
    def __init__(self, id: _Optional[int] = ..., clob_pair_id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., status: _Optional[_Union[_clob_pb2.ClobPairStatus, str]] = ..., quantum_conversion_exponent: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., subticks_per_tick: _Optional[int] = ..., step_base_quantums: _Optional[int] = ..., liquidity_tier: _Optional[int] = ...) -> None: ...

class PerpetualMarketCreateEventV2(_message.Message):
    __slots__ = ("id", "clob_pair_id", "ticker", "market_id", "status", "quantum_conversion_exponent", "atomic_resolution", "subticks_per_tick", "step_base_quantums", "liquidity_tier", "market_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    QUANTUM_CONVERSION_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_PER_TICK_FIELD_NUMBER: _ClassVar[int]
    STEP_BASE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    MARKET_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: int
    clob_pair_id: int
    ticker: str
    market_id: int
    status: _clob_pb2.ClobPairStatus
    quantum_conversion_exponent: int
    atomic_resolution: int
    subticks_per_tick: int
    step_base_quantums: int
    liquidity_tier: int
    market_type: _perpetual_pb2.PerpetualMarketType
    def __init__(self, id: _Optional[int] = ..., clob_pair_id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., status: _Optional[_Union[_clob_pb2.ClobPairStatus, str]] = ..., quantum_conversion_exponent: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., subticks_per_tick: _Optional[int] = ..., step_base_quantums: _Optional[int] = ..., liquidity_tier: _Optional[int] = ..., market_type: _Optional[_Union[_perpetual_pb2.PerpetualMarketType, str]] = ...) -> None: ...

class PerpetualMarketCreateEventV3(_message.Message):
    __slots__ = ("id", "clob_pair_id", "ticker", "market_id", "status", "quantum_conversion_exponent", "atomic_resolution", "subticks_per_tick", "step_base_quantums", "liquidity_tier", "market_type", "default_funding8hr_ppm")
    ID_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    QUANTUM_CONVERSION_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_PER_TICK_FIELD_NUMBER: _ClassVar[int]
    STEP_BASE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    MARKET_TYPE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FUNDING8HR_PPM_FIELD_NUMBER: _ClassVar[int]
    id: int
    clob_pair_id: int
    ticker: str
    market_id: int
    status: _clob_pb2.ClobPairStatus
    quantum_conversion_exponent: int
    atomic_resolution: int
    subticks_per_tick: int
    step_base_quantums: int
    liquidity_tier: int
    market_type: _perpetual_pb2.PerpetualMarketType
    default_funding8hr_ppm: int
    def __init__(self, id: _Optional[int] = ..., clob_pair_id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., status: _Optional[_Union[_clob_pb2.ClobPairStatus, str]] = ..., quantum_conversion_exponent: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., subticks_per_tick: _Optional[int] = ..., step_base_quantums: _Optional[int] = ..., liquidity_tier: _Optional[int] = ..., market_type: _Optional[_Union[_perpetual_pb2.PerpetualMarketType, str]] = ..., default_funding8hr_ppm: _Optional[int] = ...) -> None: ...

class LiquidityTierUpsertEventV1(_message.Message):
    __slots__ = ("id", "name", "initial_margin_ppm", "maintenance_fraction_ppm", "base_position_notional")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    INITIAL_MARGIN_PPM_FIELD_NUMBER: _ClassVar[int]
    MAINTENANCE_FRACTION_PPM_FIELD_NUMBER: _ClassVar[int]
    BASE_POSITION_NOTIONAL_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    initial_margin_ppm: int
    maintenance_fraction_ppm: int
    base_position_notional: int
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ..., initial_margin_ppm: _Optional[int] = ..., maintenance_fraction_ppm: _Optional[int] = ..., base_position_notional: _Optional[int] = ...) -> None: ...

class UpdateClobPairEventV1(_message.Message):
    __slots__ = ("clob_pair_id", "status", "quantum_conversion_exponent", "subticks_per_tick", "step_base_quantums")
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    QUANTUM_CONVERSION_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_PER_TICK_FIELD_NUMBER: _ClassVar[int]
    STEP_BASE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    clob_pair_id: int
    status: _clob_pb2.ClobPairStatus
    quantum_conversion_exponent: int
    subticks_per_tick: int
    step_base_quantums: int
    def __init__(self, clob_pair_id: _Optional[int] = ..., status: _Optional[_Union[_clob_pb2.ClobPairStatus, str]] = ..., quantum_conversion_exponent: _Optional[int] = ..., subticks_per_tick: _Optional[int] = ..., step_base_quantums: _Optional[int] = ...) -> None: ...

class UpdatePerpetualEventV1(_message.Message):
    __slots__ = ("id", "ticker", "market_id", "atomic_resolution", "liquidity_tier")
    ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    id: int
    ticker: str
    market_id: int
    atomic_resolution: int
    liquidity_tier: int
    def __init__(self, id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., liquidity_tier: _Optional[int] = ...) -> None: ...

class UpdatePerpetualEventV2(_message.Message):
    __slots__ = ("id", "ticker", "market_id", "atomic_resolution", "liquidity_tier", "market_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    MARKET_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: int
    ticker: str
    market_id: int
    atomic_resolution: int
    liquidity_tier: int
    market_type: _perpetual_pb2.PerpetualMarketType
    def __init__(self, id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., liquidity_tier: _Optional[int] = ..., market_type: _Optional[_Union[_perpetual_pb2.PerpetualMarketType, str]] = ...) -> None: ...

class UpdatePerpetualEventV3(_message.Message):
    __slots__ = ("id", "ticker", "market_id", "atomic_resolution", "liquidity_tier", "market_type", "default_funding8hr_ppm")
    ID_FIELD_NUMBER: _ClassVar[int]
    TICKER_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    MARKET_TYPE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FUNDING8HR_PPM_FIELD_NUMBER: _ClassVar[int]
    id: int
    ticker: str
    market_id: int
    atomic_resolution: int
    liquidity_tier: int
    market_type: _perpetual_pb2.PerpetualMarketType
    default_funding8hr_ppm: int
    def __init__(self, id: _Optional[int] = ..., ticker: _Optional[str] = ..., market_id: _Optional[int] = ..., atomic_resolution: _Optional[int] = ..., liquidity_tier: _Optional[int] = ..., market_type: _Optional[_Union[_perpetual_pb2.PerpetualMarketType, str]] = ..., default_funding8hr_ppm: _Optional[int] = ...) -> None: ...

class TradingRewardsEventV1(_message.Message):
    __slots__ = ("trading_rewards",)
    TRADING_REWARDS_FIELD_NUMBER: _ClassVar[int]
    trading_rewards: _containers.RepeatedCompositeFieldContainer[AddressTradingReward]
    def __init__(self, trading_rewards: _Optional[_Iterable[_Union[AddressTradingReward, _Mapping]]] = ...) -> None: ...

class AddressTradingReward(_message.Message):
    __slots__ = ("owner", "denom_amount")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    DENOM_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    owner: str
    denom_amount: bytes
    def __init__(self, owner: _Optional[str] = ..., denom_amount: _Optional[bytes] = ...) -> None: ...

class OpenInterestUpdateEventV1(_message.Message):
    __slots__ = ("open_interest_updates",)
    OPEN_INTEREST_UPDATES_FIELD_NUMBER: _ClassVar[int]
    open_interest_updates: _containers.RepeatedCompositeFieldContainer[OpenInterestUpdate]
    def __init__(self, open_interest_updates: _Optional[_Iterable[_Union[OpenInterestUpdate, _Mapping]]] = ...) -> None: ...

class OpenInterestUpdate(_message.Message):
    __slots__ = ("perpetual_id", "open_interest")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    OPEN_INTEREST_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    open_interest: bytes
    def __init__(self, perpetual_id: _Optional[int] = ..., open_interest: _Optional[bytes] = ...) -> None: ...

class LiquidityTierUpsertEventV2(_message.Message):
    __slots__ = ("id", "name", "initial_margin_ppm", "maintenance_fraction_ppm", "base_position_notional", "open_interest_lower_cap", "open_interest_upper_cap")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    INITIAL_MARGIN_PPM_FIELD_NUMBER: _ClassVar[int]
    MAINTENANCE_FRACTION_PPM_FIELD_NUMBER: _ClassVar[int]
    BASE_POSITION_NOTIONAL_FIELD_NUMBER: _ClassVar[int]
    OPEN_INTEREST_LOWER_CAP_FIELD_NUMBER: _ClassVar[int]
    OPEN_INTEREST_UPPER_CAP_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    initial_margin_ppm: int
    maintenance_fraction_ppm: int
    base_position_notional: int
    open_interest_lower_cap: int
    open_interest_upper_cap: int
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ..., initial_margin_ppm: _Optional[int] = ..., maintenance_fraction_ppm: _Optional[int] = ..., base_position_notional: _Optional[int] = ..., open_interest_lower_cap: _Optional[int] = ..., open_interest_upper_cap: _Optional[int] = ...) -> None: ...

class RegisterAffiliateEventV1(_message.Message):
    __slots__ = ("referee", "affiliate")
    REFEREE_FIELD_NUMBER: _ClassVar[int]
    AFFILIATE_FIELD_NUMBER: _ClassVar[int]
    referee: str
    affiliate: str
    def __init__(self, referee: _Optional[str] = ..., affiliate: _Optional[str] = ...) -> None: ...

class UpsertVaultEventV1(_message.Message):
    __slots__ = ("address", "clob_pair_id", "status")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    clob_pair_id: int
    status: _vault_pb2.VaultStatus
    def __init__(self, address: _Optional[str] = ..., clob_pair_id: _Optional[int] = ..., status: _Optional[_Union[_vault_pb2.VaultStatus, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/indexer_manager/event.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/indexer_manager/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/indexer/indexer_manager/event.proto\x12$dydxprotocol.indexer.indexer_manager\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"~\n\x1dIndexerTendermintEventWrapper\x12K\n\x05\x65vent\x18\x01 \x01(\x0b\x32<.dydxprotocol.indexer.indexer_manager.IndexerTendermintEvent\x12\x10\n\x08txn_hash\x18\x02 \x01(\t\"n\n\x17IndexerEventsStoreValue\x12S\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x43.dydxprotocol.indexer.indexer_manager.IndexerTendermintEventWrapper\"\xe2\x02\n\x16IndexerTendermintEvent\x12\x0f\n\x07subtype\x18\x01 \x01(\t\x12\x1b\n\x11transaction_index\x18\x03 \x01(\rH\x00\x12^\n\x0b\x62lock_event\x18\x04 \x01(\x0e\x32G.dydxprotocol.indexer.indexer_manager.IndexerTendermintEvent.BlockEventH\x00\x12\x13\n\x0b\x65vent_index\x18\x05 \x01(\r\x12\x0f\n\x07version\x18\x06 \x01(\r\x12\x12\n\ndata_bytes\x18\x07 \x01(\x0c\"a\n\nBlockEvent\x12\x1b\n\x17\x42LOCK_EVENT_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x42LOCK_EVENT_BEGIN_BLOCK\x10\x01\x12\x19\n\x15\x42LOCK_EVENT_END_BLOCK\x10\x02\x42\x17\n\x15ordering_within_blockJ\x04\x08\x02\x10\x03\"\xbd\x01\n\x16IndexerTendermintBlock\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\x32\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12L\n\x06\x65vents\x18\x03 \x03(\x0b\x32<.dydxprotocol.indexer.indexer_manager.IndexerTendermintEvent\x12\x11\n\ttx_hashes\x18\x04 \x03(\tBCZAgithub.com/dydxprotocol/v4-chain/protocol/indexer/indexer_managerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.indexer_manager.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/dydxprotocol/v4-chain/protocol/indexer/indexer_manager'
  _globals['_INDEXERTENDERMINTBLOCK'].fields_by_name['time']._loaded_options = None
  _globals['_INDEXERTENDERMINTBLOCK'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INDEXERTENDERMINTEVENTWRAPPER']._serialized_start=145
  _globals['_INDEXERTENDERMINTEVENTWRAPPER']._serialized_end=271
  _globals['_INDEXEREVENTSSTOREVALUE']._serialized_start=273
  _globals['_INDEXEREVENTSSTOREVALUE']._serialized_end=383
  _globals['_INDEXERTENDERMINTEVENT']._serialized_start=386
  _globals['_INDEXERTENDERMINTEVENT']._serialized_end=740
  _globals['_INDEXERTENDERMINTEVENT_BLOCKEVENT']._serialized_start=612
  _globals['_INDEXERTENDERMINTEVENT_BLOCKEVENT']._serialized_end=709
  _globals['_INDEXERTENDERMINTBLOCK']._serialized_start=743
  _globals['_INDEXERTENDERMINTBLOCK']._serialized_end=932
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as _revshare_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryMarketMapperRevenueShareParams(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryMarketMapperRevenueShareParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.MarketMapperRevenueShareParams
    def __init__(self, params: _Optional[_Union[_params_pb2.MarketMapperRevenueShareParams, _Mapping]] = ...) -> None: ...

class QueryMarketMapperRevShareDetails(_message.Message):
    __slots__ = ("market_id",)
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    market_id: int
    def __init__(self, market_id: _Optional[int] = ...) -> None: ...

class QueryMarketMapperRevShareDetailsResponse(_message.Message):
    __slots__ = ("details",)
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    details: _revshare_pb2.MarketMapperRevShareDetails
    def __init__(self, details: _Optional[_Union[_revshare_pb2.MarketMapperRevShareDetails, _Mapping]] = ...) -> None: ...

class QueryUnconditionalRevShareConfig(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryUnconditionalRevShareConfigResponse(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: _revshare_pb2.UnconditionalRevShareConfig
    def __init__(self, config: _Optional[_Union[_revshare_pb2.UnconditionalRevShareConfig, _Mapping]] = ...) -> None: ...

class QueryOrderRouterRevShare(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryOrderRouterRevShareResponse(_message.Message):
    __slots__ = ("order_router_rev_share",)
    ORDER_ROUTER_REV_SHARE_FIELD_NUMBER: _ClassVar[int]
    order_router_rev_share: _revshare_pb2.OrderRouterRevShare
    def __init__(self, order_router_rev_share: _Optional[_Union[_revshare_pb2.OrderRouterRevShare, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/redis/redis_order.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/redis/redis_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_clob__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,dydxprotocol/indexer/redis/redis_order.proto\x12\x1a\x64ydxprotocol.indexer.redis\x1a+dydxprotocol/indexer/protocol/v1/clob.proto\"\xa8\x02\n\nRedisOrder\x12\n\n\x02id\x18\x01 \x01(\t\x12=\n\x05order\x18\x02 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x46\n\x0bticker_type\x18\x04 \x01(\x0e\x32\x31.dydxprotocol.indexer.redis.RedisOrder.TickerType\x12\r\n\x05price\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\t\"Z\n\nTickerType\x12\x1b\n\x17TICKER_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15TICKER_TYPE_PERPETUAL\x10\x01\x12\x14\n\x10TICKER_TYPE_SPOT\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.redis.redis_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REDISORDER']._serialized_start=122
  _globals['_REDISORDER']._serialized_end=418
  _globals['_REDISORDER_TICKERTYPE']._serialized_start=328
  _globals['_REDISORDER_TICKERTYPE']._serialized_end=418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/protocol/v1/clob.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/protocol/v1/clob.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_subaccount__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dydxprotocol/indexer/protocol/v1/clob.proto\x12 dydxprotocol.indexer.protocol.v1\x1a\x31\x64ydxprotocol/indexer/protocol/v1/subaccount.proto\x1a\x14gogoproto/gogo.proto\"\xa2\x01\n\x0eIndexerOrderId\x12R\n\rsubaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12\x11\n\tclient_id\x18\x02 \x01(\x07\x12\x13\n\x0border_flags\x18\x03 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x04 \x01(\r\"\xf9\x07\n\x0cIndexerOrder\x12H\n\x08order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderIdB\x04\xc8\xde\x1f\x00\x12\x41\n\x04side\x18\x02 \x01(\x0e\x32\x33.dydxprotocol.indexer.protocol.v1.IndexerOrder.Side\x12\x10\n\x08quantums\x18\x03 \x01(\x04\x12\x10\n\x08subticks\x18\x04 \x01(\x04\x12\x18\n\x0egood_til_block\x18\x05 \x01(\rH\x00\x12\x1d\n\x13good_til_block_time\x18\x06 \x01(\x07H\x00\x12Q\n\rtime_in_force\x18\x07 \x01(\x0e\x32:.dydxprotocol.indexer.protocol.v1.IndexerOrder.TimeInForce\x12\x13\n\x0breduce_only\x18\x08 \x01(\x08\x12\x17\n\x0f\x63lient_metadata\x18\t \x01(\r\x12T\n\x0e\x63ondition_type\x18\n \x01(\x0e\x32<.dydxprotocol.indexer.protocol.v1.IndexerOrder.ConditionType\x12*\n\"conditional_order_trigger_subticks\x18\x0b \x01(\x04\x12T\n\x13\x62uilder_code_params\x18\x0c \x01(\x0b\x32\x37.dydxprotocol.indexer.protocol.v1.BuilderCodeParameters\x12\x1c\n\x14order_router_address\x18\r \x01(\t\x12I\n\x0ftwap_parameters\x18\x0e \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.TwapParameters\"9\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SIDE_BUY\x10\x01\x12\r\n\tSIDE_SELL\x10\x02\"\x80\x01\n\x0bTimeInForce\x12\x1d\n\x19TIME_IN_FORCE_UNSPECIFIED\x10\x00\x12\x15\n\x11TIME_IN_FORCE_IOC\x10\x01\x12\x1b\n\x17TIME_IN_FORCE_POST_ONLY\x10\x02\x12\x1e\n\x1aTIME_IN_FORCE_FILL_OR_KILL\x10\x03\"m\n\rConditionType\x12\x1e\n\x1a\x43ONDITION_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONDITION_TYPE_STOP_LOSS\x10\x01\x12\x1e\n\x1a\x43ONDITION_TYPE_TAKE_PROFIT\x10\x02\x42\x10\n\x0egood_til_oneof\"M\n\x0eTwapParameters\x12\x10\n\x08\x64uration\x18\x01 \x01(\r\x12\x10\n\x08interval\x18\x02 \x01(\r\x12\x17\n\x0fprice_tolerance\x18\x03 \x01(\r\"A\n\x15\x42uilderCodeParameters\x12\x17\n\x0f\x62uilder_address\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65_ppm\x18\x02 \x01(\r*\xf8\x01\n\x0e\x43lobPairStatus\x12 \n\x1c\x43LOB_PAIR_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43LOB_PAIR_STATUS_ACTIVE\x10\x01\x12\x1b\n\x17\x43LOB_PAIR_STATUS_PAUSED\x10\x02\x12 \n\x1c\x43LOB_PAIR_STATUS_CANCEL_ONLY\x10\x03\x12\x1e\n\x1a\x43LOB_PAIR_STATUS_POST_ONLY\x10\x04\x12!\n\x1d\x43LOB_PAIR_STATUS_INITIALIZING\x10\x05\x12%\n!CLOB_PAIR_STATUS_FINAL_SETTLEMENT\x10\x06\x42\x45ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.protocol.v1.clob_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/types'
  _globals['_INDEXERORDERID'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_INDEXERORDERID'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_INDEXERORDER'].fields_by_name['order_id']._loaded_options = None
  _globals['_INDEXERORDER'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_CLOBPAIRSTATUS']._serialized_start=1486
  _globals['_CLOBPAIRSTATUS']._serialized_end=1734
  _globals['_INDEXERORDERID']._serialized_start=155
  _globals['_INDEXERORDERID']._serialized_end=317
  _globals['_INDEXERORDER']._serialized_start=320
  _globals['_INDEXERORDER']._serialized_end=1337
  _globals['_INDEXERORDER_SIDE']._serialized_start=1020
  _globals['_INDEXERORDER_SIDE']._serialized_end=1077
  _globals['_INDEXERORDER_TIMEINFORCE']._serialized_start=1080
  _globals['_INDEXERORDER_TIMEINFORCE']._serialized_end=1208
  _globals['_INDEXERORDER_CONDITIONTYPE']._serialized_start=1210
  _globals['_INDEXERORDER_CONDITIONTYPE']._serialized_end=1319
  _globals['_TWAPPARAMETERS']._serialized_start=1339
  _globals['_TWAPPARAMETERS']._serialized_end=1416
  _globals['_BUILDERCODEPARAMETERS']._serialized_start=1418
  _globals['_BUILDERCODEPARAMETERS']._serialized_end=1483
# @@protoc_insertion_point(module_scope)
